<?php
namespace App\Http\Controllers\Behavior;
use App\Http\Controllers\Controller;
use App\Models\GeneralRecord;
use App\Models\ReleaseRecord;
use App\Repositories\Behavior\GenaralRecordRepository;
use App\Repositories\Behavior\ReleaseRecordRepository;
use App\Transformers\Behavior\GeneralRecordTransformer;
use App\Transformers\Behavior\ReleaseRecordTransformer;
use Illuminate\Http\Request;
use League\Fractal\Manager;
use League\Fractal\Pagination\IlluminatePaginatorAdapter;
use League\Fractal\Resource\Collection;
/**
 * Created by PhpStorm.
 * User: durong
 * Date: 2019/6/14
 * Time: 下午8:40
 */

class GeneralRecordController extends Controller
{
    public function __construct(GenaralRecordRepository $genaralRecordRepository)
    {
        $this->genaralRecordRepository = $genaralRecordRepository;
    }

    /**
     * 普通行为账本列表
     */
    public function index(Request $request)
    {
        $genaralList = $this->genaralRecordRepository->lists($request->all());

        if (count($genaralList)>0) {
            $behavior_trigger_times = GeneralRecord::select('trigger_type')->where('trigger_type', '!=', null)->count();//总触发数
            $behavior_effective_trigger = GeneralRecord::select('trigger_type')->where('trigger_type', 1)->count();//有效触发数
            $physical_exertion = GeneralRecord::select('physical_exertion')->sum('physical_exertion');//总消耗体力值
            $generation_quantity = GeneralRecord::select('generation_quantity')->sum('generation_quantity');//总生成彩虹豆
            $quantity_issued = GeneralRecord::select('quantity_issued')->sum('quantity_issued');//总发放彩虹豆
            foreach ($genaralList as $k => $v) {
                $v['all_trigger_times'] = $behavior_trigger_times;
                $v['all_effective_trigger'] = $behavior_effective_trigger;
                $v['physical_exertion'] = intval($physical_exertion);
                $v['generation_quantity'] = intval($generation_quantity);
                $v['quantity_issued'] = intval($quantity_issued);
            }
        }
        $fractal = new Manager();
        $resource = new Collection($genaralList, new GeneralRecordTransformer());
        $resource->setPaginator(new IlluminatePaginatorAdapter($genaralList));
        $data = $fractal->createData($resource)->toArray();
        $data['extra'] = [
            'filters' => [
                'id',
                'uid',
                'created_at',
                'trigger_type',
                'virus_behavior_id'
            ],
            'columns' => [
                'id',
                'created_at',
                'virus_behavior_id',
                'uid',
                'related_content_id',
                'content_author_id',
                'physical_exertion',
                'trigger_type',
                'generation_type',
                'absolute_progression',
                'superior_uid',
                'release_status',
                'generation_quantity',
                'quantity_issued',
                'current_comment_id',
                'superior_comment_id',
                'behavior_cycle_type',
                'name',
                'relative_series',
                'is_open',
                'bahavior_created_at',
                'all_trigger_times',
                'all_effective_trigger',
                'all_physical_exertion',
                'all_generation_quantity',
                'all_quantity_issued'
            ]
        ];
        return $data;
    }
}