<?php
/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 2019/6/11
 * Time: 10:39
 */

namespace App\Http\Controllers;

use App\Repositories\DownloadRepository;
use App\Transformers\DownloadTransformer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use League\Fractal\Manager;
use League\Fractal\Pagination\IlluminatePaginatorAdapter;
use League\Fractal\Resource\Collection;
use Illuminate\Validation\Rule;


class DownloadController extends Controller
{
    public function __construct(DownloadRepository $downloadRepository)
    {
        $this->downloadRepository = $downloadRepository;
    }

    /**
     * 下载列表
     */
    public function index(Request $request)
    {
        $productList = $this->downloadRepository->lists($request->all());
        $fractal = new Manager();
        $resource = new Collection($productList, new DownloadTransformer());
        $resource->setPaginator(new IlluminatePaginatorAdapter($productList));
        $data = $fractal->createData($resource)->toArray();
        $data['extra'] = [
            'filters' => [
                'download_type'
            ],
            'columns' => [
                'id',
                'username',
                'download_type',
                'download_status',
                'url',
                'created_at'
            ]
        ];
        return $data;
    }

    /**
     * 添加下载
     */
    public function create(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'download_type' => ['required',Rule::in('post', 'post_waste','registered_record','comment_record','release_record','general_record')],
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->downloadRepository->create($request->all());
    }
}